@@ -1709,8 +1709,10 @@ def install_newrelic_infrastructure_agent():
         shell=True,
     )
     with settings(warn_only=True):
-        sudo("apt-get -qq update || apt-get -qq update")
-    sudo("apt-get install newrelic-infra -y")
+        sudo(
+            "export DEBIAN_FRONTEND=noninteractive; apt-get -qq update || apt-get -qq update"
+        )
+    sudo("export DEBIAN_FRONTEND=noninteractive; apt-get install newrelic-infra -y")
     upload_newrelic_infrastructure_conf()
 
 
